@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2022 sqlmap developers (https://sqlmap.org/)
+Copyright (c) 2006-2024 sqlmap developers (https://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -126,6 +126,8 @@ def crawl(target, post=None, cookie=None):
                         pass
                     except ValueError:          # for non-valid links
                         pass
+                    except AssertionError:      # for invalid HTML
+                        pass
                     finally:
                         if conf.forms:
                             threadData.shared.formsFound |= len(findPageForms(content, current, False, True)) > 0
@@ -160,7 +162,7 @@ def crawl(target, post=None, cookie=None):
             except SqlmapConnectionException as ex:
                 if "page not found" in getSafeExString(ex):
                     found = False
-                    logger.warn("'sitemap.xml' not found")
+                    logger.warning("'sitemap.xml' not found")
             except:
                 pass
             finally:
@@ -196,7 +198,7 @@ def crawl(target, post=None, cookie=None):
     except KeyboardInterrupt:
         warnMsg = "user aborted during crawling. sqlmap "
         warnMsg += "will use partial list"
-        logger.warn(warnMsg)
+        logger.warning(warnMsg)
 
     finally:
         clearConsoleLine(True)
@@ -206,7 +208,7 @@ def crawl(target, post=None, cookie=None):
                 warnMsg = "no usable links found (with GET parameters)"
                 if conf.forms:
                     warnMsg += " or forms"
-                logger.warn(warnMsg)
+                logger.warning(warnMsg)
         else:
             for url in threadData.shared.value:
                 kb.targets.add((urldecode(url, kb.pageEncoding), None, None, None, None))
