@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2024 sqlmap developers (https://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -9,24 +9,22 @@ import re
 
 from lib.core.common import isDBMSVersionAtLeast
 from lib.core.common import randomStr
+from lib.core.convert import getOrds
 from plugins.generic.syntax import Syntax as GenericSyntax
 
 class Syntax(GenericSyntax):
-    def __init__(self):
-        GenericSyntax.__init__(self)
-
     @staticmethod
     def escape(expression, quote=True):
         """
         >>> from lib.core.common import Backend
         >>> Backend.setVersion('12.10')
         ['12.10']
-        >>> Syntax.escape("SELECT 'abcdefgh' FROM foobar")
-        'SELECT CHR(97)||CHR(98)||CHR(99)||CHR(100)||CHR(101)||CHR(102)||CHR(103)||CHR(104) FROM foobar'
+        >>> Syntax.escape("SELECT 'abcdefgh' FROM foobar") == "SELECT CHR(97)||CHR(98)||CHR(99)||CHR(100)||CHR(101)||CHR(102)||CHR(103)||CHR(104) FROM foobar"
+        True
         """
 
         def escaper(value):
-            return "||".join("CHR(%d)" % ord(_) for _ in value)
+            return "||".join("CHR(%d)" % _ for _ in getOrds(value))
 
         retVal = expression
 
